==> branch-0.3.zip: hadoop/src/java/org/apache/hadoop/dfs/DatanodeRegistration.java <==
package org.apache.hadoop.dfs;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

import org.apache.hadoop.io.UTF8;
import org.apache.hadoop.io.Writable;
import org.apache.hadoop.io.WritableFactories;
import org.apache.hadoop.io.WritableFactory;

/** 
 * DatanodeRegistration class conatins all information the Namenode needs
 * to identify and verify a Datanode when it contacts the Namenode.
 * This information is sent by Datanode with each communication request.
 * 
 * @author Konstantin Shvachko
 */
class DatanodeRegistration extends DatanodeID implements Writable {
  static {                                      // register a ctor
    WritableFactories.setFactory
      (DatanodeRegistration.class,
       new WritableFactory() {
         public Writable newInstance() { return new DatanodeRegistration(); }
       });
  }

  int version;            /// current Datanode version
  String registrationID;  /// a unique per namenode id; indicates   
                          /// the namenode the datanode is registered with

  /**
   * Default constructor.
   */
  public DatanodeRegistration() {
    this( 0, null, null, null );
  }
  
  /**
   * Create DatanodeRegistration
   */
  public DatanodeRegistration(int version, 
                              String nodeName, 
                              String storageID,
                              String registrationID ) {
    super(nodeName, storageID);
    this.version = version;
    this.registrationID = registrationID;
  }

  /**
   */
  public int getVersion() {
    return version;
  }
  
  /**
   */
  public String getRegistrationID() {
    return registrationID;
  }

  /////////////////////////////////////////////////
  // Writable
  /////////////////////////////////////////////////
  /**
   */
  public void write(DataOutput out) throws IOException {
    out.writeInt(this.version);
    new UTF8( this.name ).write(out);
    new UTF8( this.storageID ).write(out);
    new UTF8( this.registrationID ).write(out);   
  }

  /**
   */
  public void readFields(DataInput in) throws IOException {
    this.version = in.readInt();
    UTF8 uStr = new UTF8();
    uStr.readFields(in);
    this.name = uStr.toString();
    uStr.readFields(in);
    this.storageID = uStr.toString();
    uStr.readFields(in);
    this.registrationID = uStr.toString();   
  }
}

==> branch-0.13.zip: hadoop/src/java/org/apache/hadoop/dfs/DatanodeRegistration.java <==
package org.apache.hadoop.dfs;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

import org.apache.hadoop.io.UTF8;
import org.apache.hadoop.io.Writable;
import org.apache.hadoop.io.WritableFactories;
import org.apache.hadoop.io.WritableFactory;

/** 
 * DatanodeRegistration class conatins all information the Namenode needs
 * to identify and verify a Datanode when it contacts the Namenode.
 * This information is sent by Datanode with each communication request.
 * 
 * @author Konstantin Shvachko
 */
class DatanodeRegistration extends DatanodeID implements Writable {
  static {                                      // register a ctor
    WritableFactories.setFactory
      (DatanodeRegistration.class,
       new WritableFactory() {
         public Writable newInstance() { return new DatanodeRegistration(); }
       });
  }

  StorageInfo storageInfo;

  /**
   * Default constructor.
   */
  public DatanodeRegistration() {
    super(null, null, -1);
    this.storageInfo = new StorageInfo();
  }
  
  /**
   * Create DatanodeRegistration
   */
  public DatanodeRegistration(String nodeName, 
                              int infoPort,
                              DataStorage storage) {
    super(nodeName, storage.getStorageID(), infoPort);
    this.storageInfo = new StorageInfo(storage);
  }

  /**
   */
  public int getVersion() {
    return storageInfo.getLayoutVersion();
  }
  
  /**
   */
  public String getRegistrationID() {
    return Storage.getRegistrationID(storageInfo);
  }

  /////////////////////////////////////////////////
  // Writable
  /////////////////////////////////////////////////
  /**
   */
  public void write(DataOutput out) throws IOException {
    super.write(out);
    out.writeInt(storageInfo.getLayoutVersion());
    out.writeInt(storageInfo.getNamespaceID());
    out.writeLong(storageInfo.getCTime());
  }

  /**
   */
  public void readFields(DataInput in) throws IOException {
    super.readFields(in);
    storageInfo.layoutVersion = in.readInt();
    storageInfo.namespaceID = in.readInt();
    storageInfo.cTime = in.readLong();
  }
}
